{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "STARR-seq 04 quantification",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Bedfile containing ENCODE consensus blacklist regions to be excluded.",
                    "type": "File",
                    "id": "#main/ENCODE_blacklist_bedfile"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/input_bam_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/input_dedup_bam_files"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#main/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "scatter": "#main/bamcoverage-dedup/bam",
                    "in": [
                        {
                            "source": "#main/input_dedup_bam_files",
                            "id": "#main/bamcoverage-dedup/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamcoverage-dedup/binSize"
                        },
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/bamcoverage-dedup/blackListFileName"
                        },
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/bamcoverage-dedup/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#main/bamcoverage-dedup/normalizeUsing"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamcoverage-dedup/numberOfProcessors"
                        },
                        {
                            "valueFrom": "$(inputs.bam.nameroot.replace(/\\.[^/.]+$/, '.rpkm.bw'))",
                            "id": "#main/bamcoverage-dedup/outFileName"
                        }
                    ],
                    "out": [
                        "#main/bamcoverage-dedup/output_bam_coverage"
                    ],
                    "id": "#main/bamcoverage-dedup"
                },
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "scatter": "#main/bamcoverage-dedup-raw/bam",
                    "in": [
                        {
                            "source": "#main/input_dedup_bam_files",
                            "id": "#main/bamcoverage-dedup-raw/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamcoverage-dedup-raw/binSize"
                        },
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/bamcoverage-dedup-raw/blackListFileName"
                        },
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/bamcoverage-dedup-raw/extendReads"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamcoverage-dedup-raw/numberOfProcessors"
                        },
                        {
                            "valueFrom": "$(inputs.bam.nameroot.replace(/\\.[^/.]+$/, '.raw.bw'))",
                            "id": "#main/bamcoverage-dedup-raw/outFileName"
                        }
                    ],
                    "out": [
                        "#main/bamcoverage-dedup-raw/output_bam_coverage"
                    ],
                    "id": "#main/bamcoverage-dedup-raw"
                },
                {
                    "run": "#deeptools-bamcoverage.cwl",
                    "scatter": "#main/bamcoverage-with-dups/bam",
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/bamcoverage-with-dups/bam"
                        },
                        {
                            "valueFrom": "${return 1}",
                            "id": "#main/bamcoverage-with-dups/binSize"
                        },
                        {
                            "source": "#main/ENCODE_blacklist_bedfile",
                            "id": "#main/bamcoverage-with-dups/blackListFileName"
                        },
                        {
                            "valueFrom": "$(true)",
                            "id": "#main/bamcoverage-with-dups/extendReads"
                        },
                        {
                            "valueFrom": "RPKM",
                            "id": "#main/bamcoverage-with-dups/normalizeUsing"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/bamcoverage-with-dups/numberOfProcessors"
                        },
                        {
                            "valueFrom": "$(inputs.bam.nameroot.replace(/\\.[^/.]+$/, '.rpkm.bw'))",
                            "id": "#main/bamcoverage-with-dups/outFileName"
                        }
                    ],
                    "out": [
                        "#main/bamcoverage-with-dups/output_bam_coverage"
                    ],
                    "id": "#main/bamcoverage-with-dups"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "doc": "Normalized by RPKM bigWig files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamcoverage-dedup/output_bam_coverage",
                    "id": "#main/bw_dedup_norm_files"
                },
                {
                    "doc": "Raw 1bp bigWig files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamcoverage-dedup-raw/output_bam_coverage",
                    "id": "#main/bw_dedup_raw_files"
                },
                {
                    "doc": "Normalized by RPKM bigWig files.",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bamcoverage-with-dups/output_bam_coverage",
                    "id": "#main/bw_with_dups_norm_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "usage: An example usage is:$ bamCoverage -b reads.bam -o coverage.bw\n\nThis tool takes an alignment of reads or fragments as input (BAM file) and\ngenerates a coverage track (bigWig or bedGraph) as output. The coverage is\ncalculated as the number of reads per bin, where bins are short consecutive\ncounting windows of a defined size. It is possible to extended the length of\nthe reads to better reflect the actual fragment length. *bamCoverage* offers\nnormalization by scaling factor, Reads Per Kilobase per Million mapped reads\n(RPKM), and 1x depth (reads per genome coverage, RPGC).\nRequired arguments:\n  --bam BAM file, -b BAM file\n                        BAM file to process (default: None)\nOutput:\n  --outFileName FILENAME, -o FILENAME\n                        Output file name. (default: None)\n  --outFileFormat {bigwig,bedgraph}, -of {bigwig,bedgraph}\n                        Output file type. Either \"bigwig\" or \"bedgraph\".\n                        (default: bigwig)\nOptional arguments:\n  --help, -h            show this help message and exit\n  --scaleFactor SCALEFACTOR\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the \u2013binSize is set to 20 and the \u2013smoothLength is\n                        set to 60, then, for each bin, the average of the bin\n                        and its left and right neighbors is considered.\n                        Any value smaller than \u2013binSize will be ignored and\n                        no smoothing will be applied. (default: 1.0)\n  --MNase               Determine nucleosome positions from MNase-seq data.\n                        Only 3 nucleotides at the center of each fragment are\n                        counted. The fragment ends are defined by the two mate\n                        reads. Only fragment lengthsbetween 130 - 200 bp are\n                        considered to avoid dinucleosomes or other\n                        artifacts.*NOTE*: Requires paired-end data. A bin size\n                        of 1 is recommended. (default: False)\n  --filterRNAstrand {forward,reverse}\n                        Selects RNA-seq reads (single-end or paired-end) in\n                        the given strand. (default: None)\n  --version             show program's version number and exit\n  --binSize INT bp, -bs INT bp\n                        Size of the bins, in bases, for the output of the\n                        bigwig/bedgraph file. (default: 50)\n  --region CHR:START:END, -r CHR:START:END\n                        Region of the genome to limit the operation to - this\n                        is useful when testing parameters to reduce the\n                        computing time. The format is chr:start:end, for\n                        example --region chr10 or --region\n                        chr10:456700:891000. (default: None)\n  --blackListFileName BED file, -bl BED file\n                        A BED file containing regions that should be excluded\n                        from all analyses. Currently this works by rejecting\n                        genomic chunks that happen to overlap an entry.\n                        Consequently, for BAM files, if a read partially\n                        overlaps a blacklisted region or a fragment spans over\n                        it, then the read/fragment might still be considered.\n                        (default: None)\n  --numberOfProcessors INT, -p INT\n                        Number of processors to use. Type \"max/2\" to use half\n                        the maximum number of processors or \"max\" to use all\n                        available processors. (default: max/2)\n  --verbose, -v         Set to see processing messages. (default: False)\nRead coverage normalization options:\n  --normalizeTo1x EFFECTIVE GENOME SIZE LENGTH\n                        Report read coverage normalized to 1x sequencing depth\n                        (also known as Reads Per Genomic Content (RPGC)).\n                        Sequencing depth is defined as: (total number of\n                        mapped reads * fragment length) / effective genome\n                        size. The scaling factor used is the inverse of the\n                        sequencing depth computed for the sample to match the\n                        1x coverage. To use this option, the effective genome\n                        size has to be indicated after the option. The\n                        effective genome size is the portion of the genome\n                        that is mappable. Large fractions of the genome are\n                        stretches of NNNN that should be discarded. Also, if\n                        repetitive regions were not included in the mapping of\n                        reads, the effective genome size needs to be adjusted\n                        accordingly. Common values are: mm9: 2,150,570,000;\n                        hg19:2,451,960,000; dm3:121,400,000 and\n                        ce10:93,260,000. See Table 2 of http://www.plosone.org\n                        /article/info:doi/10.1371/journal.pone.0030377 or http\n                        ://www.nature.com/nbt/journal/v27/n1/fig_tab/nbt.1518_\n                        T1.html for several effective genome sizes. (default:\n                        None)\n--ignoreForNormalization IGNOREFORNORMALIZATION [IGNOREFORNORMALIZATION ...]\n                        A list of space-delimited chromosome names containing\n                        those chromosomes that should be excluded for\n                        computing the normalization. This is useful when\n                        considering samples with unequal coverage across\n                        chromosomes, like male samples. An usage examples is\n                        --ignoreForNormalization chrX chrM. (default: None)\n  --skipNonCoveredRegions, --skipNAs\n                        This parameter determines if non-covered regions\n                        (regions without overlapping reads) in a BAM file\n                        should be skipped. The default is to treat those\n                        regions as having a value of zero. The decision to\n                        skip non-covered regions depends on the interpretation\n                        of the data. Non-covered regions may represent, for\n                        example, repetitive regions that should be skipped.\n                        (default: False)\n  --smoothLength INT bp\n                        The smooth length defines a window, larger than the\n                        binSize, to average the number of reads. For example,\n                        if the --binSize is set to 20 and the --smoothLength\n                        is set to 60, then, for each bin, the average of the\n                        bin and its left and right neighbors is considered.\n                        Any value smaller than --binSize will be ignored and\n                        no smoothing will be applied. (default: None)\nRead processing options:\n  --extendReads [INT bp], -e [INT bp]\n                        This parameter allows the extension of reads to\n                        fragment size. If set, each read is extended, without\n                        exception. *NOTE*: This feature is generally NOT\n                        recommended for spliced-read data, such as RNA-seq, as\n                        it would extend reads over skipped regions. *Single-\n                        end*: Requires a user specified value for the final\n                        fragment length. Reads that already exceed this\n                        fragment length will not be extended. *Paired-end*:\n                        Reads with mates are always extended to match the\n                        fragment size defined by the two read mates. Unmated\n                        reads, mate reads that map too far apart (>4x fragment\n                        length) or even map to different chromosomes are\n                        treated like single-end reads. The input of a fragment\n                        length value is optional. If no value is specified, it\n                        is estimated from the data (mean of the fragment size\n                        of all mate reads). (default: False)\n  --ignoreDuplicates    If set, reads that have the same orientation and start\n                        position will be considered only once. If reads are\n                        paired, the mate's position also has to coincide to\n                        ignore a read. (default: False)\n  --minMappingQuality INT\n                        If set, only reads that have a mapping quality score\n                        of at least this are considered. (default: None)\n  --centerReads         By adding this option, reads are centered with respect\n                        to the fragment length. For paired-end data, the read\n                        is centered at the fragment length defined by the two\n                        ends of the fragment. For single-end data, the given\n                        fragment length is used. This option is useful to get\n                        a sharper signal around enriched regions. (default:\n                        False)\n  --samFlagInclude INT  Include reads based on the SAM flag. For example, to\n                        get only reads that are the first mate, use a flag of\n                        64. This is useful to count properly paired reads only\n                        once, as otherwise the second mate will be also\n                        considered for the coverage. (default: None)\n  --samFlagExclude INT  Exclude reads based on the SAM flag. For example, to\n                        get only reads that map to the forward strand, use\n                        --samFlagExclude 16, where 16 is the SAM flag for\n                        reads that map to the reverse strand. (default: None)\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/deeptools:3.0.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--MNase"
                    },
                    "doc": "Determine nucleosome positions from MNase-seq data.\nOnly 3 nucleotides at the center of each fragment are\ncounted. The fragment ends are defined by the two mate\nreads. Only fragment lengthsbetween 130 - 200 bp are\nconsidered to avoid dinucleosomes or other\nartifacts.*NOTE*: Requires paired-end data. A bin size\nof 1 is recommended. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/MNase"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "doc": "BAM file to process ",
                    "id": "#deeptools-bamcoverage.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--binSize"
                    },
                    "doc": "INT bp\nSize of the bins, in bases, for the output of the\nbigwig/bedgraph file. (default: 50)\n",
                    "id": "#deeptools-bamcoverage.cwl/binSize"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--blackListFileName"
                    },
                    "doc": "BED file\nA BED file containing regions that should be excluded\nfrom all analyses. Currently this works by rejecting\ngenomic chunks that happen to overlap an entry.\nConsequently, for BAM files, if a read partially\noverlaps a blacklisted region or a fragment spans over\nit, then the read/fragment might still be considered.\n(default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/blackListFileName"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--centerReads"
                    },
                    "doc": "By adding this option, reads are centered with respect\nto the fragment length. For paired-end data, the read\nis centered at the fragment length defined by the two\nends of the fragment. For single-end data, the given\nfragment length is used. This option is useful to get\na sharper signal around enriched regions. (default:\nFalse)\n",
                    "id": "#deeptools-bamcoverage.cwl/centerReads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extendReads"
                    },
                    "doc": "INT bp\nThis parameter allows the extension of reads to\nfragment size. If set, each read is extended, without\nexception. *NOTE*: This feature is generally NOT\nrecommended for spliced-read data, such as RNA-seq, as\nit would extend reads over skipped regions. *Single-\nend*: Requires a user specified value for the final\nfragment length. Reads that already exceed this\nfragment length will not be extended. *Paired-end*:\nReads with mates are always extended to match the\nfragment size defined by the two read mates. Unmated\nreads, mate reads that map too far apart (>4x fragment\nlength) or even map to different chromosomes are\ntreated like single-end reads. The input of a fragment\nlength value is optional. If no value is specified, it\nis estimated from the data (mean of the fragment size\nof all mate reads). (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/extendReads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--filterRNAstrand"
                    },
                    "doc": "{forward,reverse}\nSelects RNA-seq reads (single-end or paired-end) in\nthe given strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/filterRNAstrand"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreDuplicates"
                    },
                    "doc": "If set, reads that have the same orientation and start\nposition will be considered only once. If reads are\npaired, the mate's position also has to coincide to\nignore a read. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreDuplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ignoreForNormalization"
                    },
                    "doc": "A list of space-delimited chromosome names containing those chromosomes\nthat should be excluded for computing the normalization. This is useful\nwhen considering samples with unequal coverage across chromosomes, like\nmale samples. An usage examples is \u2013ignoreForNormalization chrX chrM.\n",
                    "id": "#deeptools-bamcoverage.cwl/ignoreForNormalization"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--minMappingQuality"
                    },
                    "doc": "INT\nIf set, only reads that have a mapping quality score\nof at least this are considered. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/minMappingQuality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--normalizeUsing"
                    },
                    "doc": "Possible choices: RPKM, CPM, BPM, RPGC\n\nUse one of the entered methods to normalize the number of reads per bin.\nBy default, no normalization is performed. RPKM = Reads Per Kilobase per\nMillion mapped reads; CPM = Counts Per Million mapped reads, same as\nCPM in RNA-seq; BPM = Bins Per Million mapped reads, same as TPM in\nRNA-seq; RPGC = reads per genomic content (1x normalization);\nMapped reads are considered after blacklist filtering (if applied).\nRPKM (per bin) = number of reads per bin / (number of mapped reads (in millions) * bin length (kb)).\nCPM (per bin) = number of reads per bin / number of mapped reads (in millions).\nBPM (per bin) = number of reads per bin / sum of all reads per bin (in millions).\nRPGC (per bin) = number of reads per bin / scaling factor for 1x average coverage.\nThis scaling factor, in turn, is determined from the sequencing depth:\n(total number of mapped reads * fragment length) / effective genome size.\nThe scaling factor used is the inverse of the sequencing depth\ncomputed for the sample to match the 1x coverage.\nThis option requires \u2013effectiveGenomeSize.\nEach read is considered independently, if you want to only count one\nmate from a pair in paired-end data, then use\nthe \u2013samFlagInclude/\u2013samFlagExclude options.\n",
                    "id": "#deeptools-bamcoverage.cwl/normalizeUsing"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--numberOfProcessors"
                    },
                    "doc": "INT\nNumber of processors to use. Type \"max/2\" to use half\nthe maximum number of processors or \"max\" to use all\navailable processors. (default: max/2)\n",
                    "id": "#deeptools-bamcoverage.cwl/numberOfProcessors"
                },
                {
                    "type": "string",
                    "default": "bigwig",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--outFileFormat"
                    },
                    "doc": "{bigwig,bedgraph}, -of {bigwig,bedgraph}\nOutput file type. Either \"bigwig\" or \"bedgraph\".\n(default: bigwig)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileFormat"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "FILENAME\nOutput file name. (default: input BAM filename with bigwig [*.bw] or bedgraph [*.bdg] extension.)\n",
                    "id": "#deeptools-bamcoverage.cwl/outFileName"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Suffix used for output file (input BAM filename + suffix)",
                    "id": "#deeptools-bamcoverage.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--region"
                    },
                    "doc": "CHR:START:END\nRegion of the genome to limit the operation to - this\nis useful when testing parameters to reduce the\ncomputing time. The format is chr:start:end, for\nexample --region chr10 or --region\nchr10:456700:891000. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/region"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagExclude"
                    },
                    "doc": "INT  \nExclude reads based on the SAM flag. For example, to\nget only reads that map to the forward strand, use\n--samFlagExclude 16, where 16 is the SAM flag for\nreads that map to the reverse strand. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagExclude"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samFlagInclude"
                    },
                    "doc": "INT  \nInclude reads based on the SAM flag. For example, to\nget only reads that are the first mate, use a flag of\n64. This is useful to count properly paired reads only\nonce, as otherwise the second mate will be also\nconsidered for the coverage. (default: None)\n",
                    "id": "#deeptools-bamcoverage.cwl/samFlagInclude"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--scaleFactor"
                    },
                    "doc": "The smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the \u2013binSize is set to 20 and the \u2013smoothLength is\nset to 60, then, for each bin, the average of the bin\nand its left and right neighbors is considered.\nAny value smaller than \u2013binSize will be ignored and\nno smoothing will be applied. (default: 1.0)\n",
                    "id": "#deeptools-bamcoverage.cwl/scaleFactor"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--skipNonCoveredRegions"
                    },
                    "doc": "--skipNonCoveredRegions, --skipNAs\nThis parameter determines if non-covered regions\n(regions without overlapping reads) in a BAM file\nshould be skipped. The default is to treat those\nregions as having a value of zero. The decision to\nskip non-covered regions depends on the interpretation\nof the data. Non-covered regions may represent, for\nexample, repetitive regions that should be skipped.\n(default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/skipNonCoveredRegions"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--smoothLength"
                    },
                    "doc": "INT bp\nThe smooth length defines a window, larger than the\nbinSize, to average the number of reads. For example,\nif the --binSize is set to 20 and the --smoothLength\nis set to 60, then, for each bin, the average of the\nbin and its left and right neighbors is considered.\nAny value smaller than --binSize will be ignored and\nno smoothing will be applied. (default: None)\nRead processing options:\n",
                    "id": "#deeptools-bamcoverage.cwl/smoothLength"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "--verbose         \nSet to see processing messages. (default: False)\n",
                    "id": "#deeptools-bamcoverage.cwl/verbose"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--version"
                    },
                    "doc": "show program's version number and exit",
                    "id": "#deeptools-bamcoverage.cwl/version"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }"
                    },
                    "id": "#deeptools-bamcoverage.cwl/output_bam_coverage"
                }
            ],
            "baseCommand": "bamCoverage",
            "arguments": [
                {
                    "valueFrom": "${ if (inputs.outFileName) return inputs.outFileName; if (inputs.output_suffix) return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix; if (inputs.outFileFormat == \"bedgraph\") return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bdg\"; return inputs.bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".bw\"; }",
                    "prefix": "--outFileName",
                    "position": 3
                }
            ],
            "id": "#deeptools-bamcoverage.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
